Package: epoxy
Title: String Interpolation for Documents, Reports and Apps
Version: 1.0.0
Authors@R: c(
    person("Garrick", "Aden-Buie", , "garrick@adenbuie.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7111-0077")),
    person("Kushagra", "Gour", role = "ctb",
           comment = "hint.css"),
    person("The mustache.js community", role = "ctb",
           comment = "mustache.js")
  )
Description: Extra strength 'glue' for data-driven templates. String
    interpolation for 'Shiny' apps or 'R Markdown' and 'knitr'-powered
    'Quarto' documents, built on the 'glue' and 'whisker' packages.
License: MIT + file LICENSE
URL: https://pkg.garrickadenbuie.com/epoxy/,
        https://github.com/gadenbuie/epoxy
BugReports: https://github.com/gadenbuie/epoxy/issues
Depends: R (>= 3.6.0)
Imports: and, glue (>= 1.5.0), htmltools, knitr (>= 1.37), lifecycle,
        purrr, rlang, rmarkdown, scales (>= 1.1.0), tools, whisker
Suggests: cleanrmd, commonmark, dbplyr, debugme, dplyr, pandoc, shiny,
        shinytest2, testthat
VignetteBuilder: cleanrmd, knitr, rmarkdown
Config/Needs/rcmdcheck: RSQLite, rstudio/chromote
Config/Needs/website: rstudio/rmarkdown, gadenbuie/grkgdown
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-09-19 18:33:04 UTC; garrick
Author: Garrick Aden-Buie [aut, cre] (<https://orcid.org/0000-0002-7111-0077>),
  Kushagra Gour [ctb] (hint.css),
  The mustache.js community [ctb] (mustache.js)
Maintainer: Garrick Aden-Buie <garrick@adenbuie.com>
Repository: CRAN
Date/Publication: 2023-09-20 00:00:02 UTC
Built: R 4.2.0; ; 2023-09-24 21:41:34 UTC; unix
