# Generated by roxygen2: do not edit by hand

export(engine_pick)
export(epoxy)
export(epoxyHTML)
export(epoxy_html)
export(epoxy_latex)
export(epoxy_mustache)
export(epoxy_style)
export(epoxy_style_apply)
export(epoxy_style_bold)
export(epoxy_style_code)
export(epoxy_style_collapse)
export(epoxy_style_get)
export(epoxy_style_html)
export(epoxy_style_inline)
export(epoxy_style_italic)
export(epoxy_style_set)
export(epoxy_style_wrap)
export(epoxy_transform)
export(epoxy_transform_apply)
export(epoxy_transform_bold)
export(epoxy_transform_code)
export(epoxy_transform_collapse)
export(epoxy_transform_get)
export(epoxy_transform_html)
export(epoxy_transform_inline)
export(epoxy_transform_italic)
export(epoxy_transform_set)
export(epoxy_transform_wrap)
export(epoxy_use_chunk)
export(epoxy_use_file)
export(renderEpoxyHTML)
export(render_epoxy)
export(run_epoxy_example_app)
export(ui_epoxy_html)
export(ui_epoxy_markdown)
export(ui_epoxy_mustache)
export(ui_epoxy_whisker)
export(use_epoxy_glue_engine)
export(use_epoxy_knitr_engines)
importFrom(glue,glue)
importFrom(glue,glue_collapse)
importFrom(glue,glue_data)
importFrom(htmltools,HTML)
importFrom(lifecycle,deprecated)
