



if not exist %PREFIX%\\Library\\include\\epoxy\\common.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\bin\\epoxy-0.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\epoxy.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
